Citations
=========

When referring to this software package, please be sure to include the package
and specify which version you used `<https://doi.org/10.5281/zenodo.1214206>`_.
Note that this DOI will always point to the latest version of the code.  A list
of DOIs for all versions can be found at the Zenodo page above. The version can
by found by printing :py:attr:`apexpy.__version__`.  We also recommend citing a
reference to the coordinate system you use.  More relevant references can be
found in :ref:`authors`.

Example for citation in BibTex for a generalized version:

.. code::

  @misc{apexpy,
    author       = {van der Meeren, Christer and
                    Laundal, Karl M. and
		    Burrell, Angeline G. and
		    Lamarche, Leslie and
		    Starr, Gregory and
		    Reimer, Ashton and
		    Morschhauser, Achim and
		    Michaelis, Ingo},
    title        = {ApexPy vX.Y.Z},
    year         = 2024,
    doi          = {10.5281/zenodo.1214206},
    url          = {https://github.com/aburrell/apexpy}
  }
